@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright 2019-2020 Pelion
+# Copyright 2019-2021 Pelion
 #
 # SPDX-License-Identifier: Apache-2.0
 #
@@ -25,20 +25,21 @@ from typing import Type
 import jsonschema
 import yaml
 
-from manifesttool.mtool.actions import existing_file_path_arg_factory
-from manifesttool.mtool.actions import non_negative_int_arg_factory
+from manifesttool.common.common_helpers import get_argument_path
+from manifesttool.common.common_helpers import get_non_negative_int_argument
 from manifesttool.mtool.actions import semantic_version_arg_factory
+from manifesttool.mtool.actions import semver_as_tuple_arg_factory
 from manifesttool.mtool.asn1 import ManifestAsnCodecBase
 from manifesttool.mtool.asn1.v1 import ManifestAsnCodecV1
 from manifesttool.mtool import ecdsa_helper
 
 MTOOL_PATH = Path(__file__).resolve().parent.parent
 
+logger = logging.getLogger('manifest-tool-create')
+
 
 class CreateAction:
 
-    logger = logging.getLogger('manifest-tool-create')
-
     @staticmethod
     def register_parser_args(
             parser: argparse.ArgumentParser, schema_version: str):
@@ -64,16 +65,25 @@ class CreateAction:
         )
 
         if schema_version == 'v1':
-            optional.add_argument(
+            version_group = optional.add_mutually_exclusive_group()
+            version_group.add_argument(
                 '-v', '--fw-version',
-                type=non_negative_int_arg_factory,
+                type=get_non_negative_int_argument,
                 help='Version number (integer) of the candidate image. '
                      'Default: current epoch time.',
                 default=int(time.time())
             )
+            version_group.add_argument(
+                '--fw-migrate-ver',
+                type=semver_as_tuple_arg_factory,
+                help='Version number of the candidate image in '
+                     'SemVer format. NOTE: Use to upgrade from '
+                     'v1 manifest schema to a later schema.'
+            )
+
             required.add_argument(
                 '--update-certificate',
-                type=existing_file_path_arg_factory,
+                type=get_argument_path,
                 help='Path to the update certificate file.',
                 required=True
             )
@@ -81,7 +91,10 @@ class CreateAction:
             required.add_argument(
                 '-v', '--fw-version',
                 type=semantic_version_arg_factory,
-                help='Version number of the candidate image in SemVer format.',
+                help='Version number of the candidate image in SemVer format. '
+                     'Min. 0.0.1, max 999.999.999. '
+                     'Must be bigger than the version currently '
+                     'in the device(s).',
                 required=True
             )
 
@@ -112,6 +125,16 @@ class CreateAction:
 
         codec = asn1_codec_class()
 
+        # validate input against manifest-input-schema.json
+        schema_path = MTOOL_PATH / 'manifest-input-schema.json'
+        with schema_path.open('rb') as fh:
+            input_schema = yaml.safe_load(fh)
+            if isinstance(codec, ManifestAsnCodecV1):
+                # priority field is optional for v1
+                # delete it from required list
+                input_schema['required'].remove('priority')
+            jsonschema.validate(input_cfg, input_schema)
+
         raw_signature = True
         if isinstance(codec, ManifestAsnCodecV1):
             raw_signature = False
@@ -136,7 +159,14 @@ class CreateAction:
         signature = ecdsa_helper.ecdsa_sign(der_manifest, pem_key_data)
         if raw_signature:
             signature = ecdsa_helper.signature_der_to_raw(signature)
-        return codec.get_der_signed_resource(signature)
+        manifest_bin = codec.get_der_signed_resource(signature)
+
+        logger.info('Attention: When updating Mbed OS devices,'
+                    ' candidate features must match the device\'s'
+                    ' bootloader features. Incompatibility may'
+                    ' result in damaged devices.')
+
+        return manifest_bin
 
     @classmethod
     def entry_point(
@@ -144,16 +174,18 @@ class CreateAction:
             args: argparse.Namespace,
             asn1_codec: Type[ManifestAsnCodecBase]
     ) -> None:
+
         input_cfg = yaml.safe_load(args.config)
-        schema_path = MTOOL_PATH / 'manifest-input-schema.json'
-        with schema_path.open('rb') as fh:
-            input_schema = yaml.safe_load(fh)
-        jsonschema.validate(input_cfg, input_schema)
+
+        if getattr(args, 'fw_migrate_ver', None):
+            fw_version = args.fw_migrate_ver[0]
+        else:
+            fw_version = args.fw_version
 
         manifest_bin = cls.do_create(
             pem_key_data=args.key.read(),
             input_cfg=input_cfg,
-            fw_version=args.fw_version,
+            fw_version=fw_version,
             update_certificate=getattr(args, 'update_certificate', None),
             asn1_codec_class=asn1_codec
         )
